@@ -4,7 +4,7 @@ from pocsuite3.lib.core.common import (encoder_bash_payload, check_port,
                                        get_host_ipv6, single_time_warn_message)
 from pocsuite3.lib.core.data import conf, kb, logger, paths
 from pocsuite3.lib.core.datatype import AttribDict
-from pocsuite3.lib.core.common import OrderedSet, OrderedDict
+from pocsuite3.lib.core.common import OrderedSet, OrderedDict, mosaic, urlparse
 from pocsuite3.lib.core.enums import PLUGIN_TYPE, POC_CATEGORY, VUL_TYPE
 from pocsuite3.lib.core.interpreter_option import (OptBool, OptDict, OptFloat,
                                                    OptInteger, OptIP, OptItems,
@@ -39,7 +39,7 @@ __all__ = ('requests', 'PluginBase', 'register_plugin', 'PLUGIN_TYPE',
            'DEFAULT_LISTENER_PORT', 'load_file_to_module', 'OrderedDict', 'OrderedSet',
            'load_string_to_module', 'single_time_warn_message', 'CEye',
            'Seebug', 'ZoomEye', 'Shodan', 'Fofa', 'Quake', 'Hunter', 'Censys',
-           'PHTTPServer', 'REVERSE_PAYLOAD', 'get_listener_ip',
+           'PHTTPServer', 'REVERSE_PAYLOAD', 'get_listener_ip', 'mosaic', 'urlparse',
            'get_listener_port', 'get_results', 'init_pocsuite',
            'start_pocsuite', 'get_poc_options', 'crawl', 'OSShellcodes',
            'WebShell', 'OptDict', 'OptIP', 'OptPort', 'OptBool', 'OptInteger',
