@@ -62,7 +62,8 @@ class TestCase(unittest.TestCase):
             request.add_option("--host", dest="host", help="HTTP Host header value")
             request.add_option("--referer", dest="referer", help="HTTP Referer header value")
             request.add_option("--user-agent", dest="agent", help="HTTP User-Agent header value (default random)")
-            request.add_option("--proxy", dest="proxy", help="Use a proxy to connect to the target URL")
+            request.add_option("--proxy", dest="proxy",
+                               help="Use a proxy to connect to the target URL (protocol://host:port)")
             request.add_option("--proxy-cred", dest="proxy_cred",
                                help="Proxy authentication credentials (name:password)")
             request.add_option("--timeout", dest="timeout", type=float, default=10,
@@ -125,6 +126,8 @@ class TestCase(unittest.TestCase):
 
             # Optimization options
             optimization = OptionGroup(parser, "Optimization", "Optimization options")
+            optimization.add_option("-o", "--output", dest="output_path",
+                                    help="Output file to write (JSON Lines format)")
             optimization.add_option("--plugins", dest="plugins", action="store", default=None,
                                     help="Load plugins to execute")
             optimization.add_option("--pocs-path", dest="pocs_path", action="store", default=None,
